#!/usr/bin/env python
# ex:ts=4:sw=4:sts=4:et
# -*- tab-width: 4; c-basic-offset: 4; indent-tabs-mode: nil -*-
#
# Copyright (C) 2003  Chris Larson
# Modified heavily, copyright (c) 2021, Al Stone
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 2 as
# published by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.

import os, sys
sys.path.append(os.path.join(os.path.dirname(__file__), "lib"))
from bb import __version__

from glob import glob
from distutils.core import setup


setup(name='bitbake',
      version = __version__,
      description = 'BitBake build tool',
      author = 'BitBake Development Team',
      author_email = 'bitbake-devel@lists.openembedded.org',
      url = 'https://github.com/openembedded/bitbake',
      license = 'GPLv2',
      maintainer = 'Al Stone',
      maintainer_email = 'ahs3@fedoraproject.org',

      package_dir = {"": "lib"},
      packages = ["bb", "bb.fetch2", "bb.parse", "bb.parse.parse_py",
                  "bb.pysh", "bb.server", "bb.tests", "bb.ui",
                  "bblayers", "bs4", "hashserv", "layerindexlib",
                  "ply", "progressbar", "prserv", "simplediff",
                  "toaster",
                 ],
      py_modules = ["codegen", "pyinotify"],
      scripts = ["bin/bitbake", "bin/bitbake-diffsigs",
                 "bin/bitbake-hashclient", "bin/bitbake-hashserv",
                 "bin/bitbake-layers", "bin/bitbake-prserv",
                 "bin/bitbake-selftest", "bin/bitbake-worker",
                 "bin/git-make-shallow",
                 "bin/toaster", "bin/toaster-eventreplay"
                ],

      data_files = [ ("share/doc/bitbake", ["AUTHORS"]),
                    ("share/doc/bitbake", ["toaster-requirements.txt"]),
                    ("share/doc/bitbake", ["ChangeLog"]),
                    ("share/doc/bitbake", ["README"]),
                    ("share/doc/bitbake", ["TODO"]),
                    ("share/bitbake", glob("classes/*")),
                    ("share/bitbake", glob("conf/*")),
                   ],

      requires = ["ply", "progressbar"],

      long_description = "BitBake is a generic task execution engine that allows shell and Python tasks to be run efficiently and in parallel while working within complex inter-task dependency constraints.  One of BitBake's main users, OpenEmbedded, takes this core and builds embedded Linux software stacks using a task-oriented approach.",
)
